#!/usr/bin/env python3

from rich.console import Console

class Okland():
    """
    Generic functions
    
    """
    __Console__ = Console()


    def __toConsole__(self, message, style="dim"):
        self.__Console__.print(message, style=style)
        return True


#!/usr/bin/env python3

from utils.generics import *
from utils.kics import *
import fire

def main():
    """
    handle resulsts from static code analysis toolings. 
    
    most prominent create metrics and send results over to a prometheus pushgateway.

    """
    fire.Fire({
      'kics': Kics,
    })
  
if __name__ == '__main__':
    """
    okland
    """
    main()